@@ -12,9 +12,10 @@ use std::{
     str::FromStr,
 };
 
-use serde::{Deserialize, Serialize};
+use serde::{Deserialize, Serialize, de::Deserializer};
 
 pub use crate::ParseError;
+use crate::utils::WhitespaceListVisitor;
 
 /// Debian architectures
 ///
@@ -158,6 +159,16 @@ impl FromStr for Architecture {
     }
 }
 
+/// Deserialize a list of architectures into a `Vec<Architecture>`
+pub(crate) fn deserialize_architectures<'de, D>(
+    deserializer: D,
+) -> Result<Vec<Architecture>, D::Error>
+where
+    D: Deserializer<'de>,
+{
+    deserializer.deserialize_str(WhitespaceListVisitor::new("Architecture"))
+}
+
 #[cfg(test)]
 mod test {
     use super::Architecture;
